## History

### 2015.03.02

0.3.4 release

- create new event loop if using in a thread

### 2015.02.28

0.3.3 release

- fixed Pool's potential thread unsafe problem
- fixed Yielder hangs when no items to yield
- add pool size argument to yielder family

### 2015.02.27

0.3.2 release

- typo fix

0.3.1 release

- add put method for manually yield items

0.3.0 release

- add Yielder and OrderedYielder to replace Bag and OrderedBag
- fix thread safe problem #2 in Yielder and Group mixed usage

### 2015.02.26

0.2.1 release

- fix thread unsafe problem

### 2015.02.26

0.2.0 release

- add Bag and OrderedBag
- rename to "aioutils"

### 2015.02.25

0.1.2 release

- fix some release problems

0.1.1 release

- basic group and pool implemenation


### 2015.02.23

ideas, prototypes
